/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_cxoNSdWS);
  numBytes += sPhasor_k_init(&sPhasor_RwgZHe59, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_IA2xiq1W);
  numBytes += sRPole_init(&sRPole_Y8PF3DRs);
  numBytes += sRPole_init(&sRPole_zAOBbCX4);
  numBytes += sTabhead_init(&sTabhead_qMSZysbV, &hTable_5ZFAQ6nt);
  numBytes += sTabread_init(&sTabread_Upfpy28a, &hTable_5ZFAQ6nt, false);
  numBytes += sTabread_init(&sTabread_lxH2Tfdi, &hTable_5ZFAQ6nt, false);
  numBytes += sLine_init(&sLine_wIVYSpXS);
  numBytes += sTabhead_init(&sTabhead_njW7YN9k, &hTable_GK32SWDU);
  numBytes += sTabread_init(&sTabread_2vsqbJxw, &hTable_GK32SWDU, false);
  numBytes += sTabread_init(&sTabread_TkHFRHl0, &hTable_GK32SWDU, false);
  numBytes += sLine_init(&sLine_45lME5CF);
  numBytes += sTabwrite_init(&sTabwrite_9MG4p8NN, &hTable_GK32SWDU);
  numBytes += sTabwrite_init(&sTabwrite_M0POJ8FO, &hTable_5ZFAQ6nt);
  numBytes += cVar_init_f(&cVar_bmNDR1OK, 0.0f);
  numBytes += cVar_init_f(&cVar_JK7Fao6W, 0.0f);
  numBytes += cVar_init_f(&cVar_lvnEk7ka, 0.0f);
  numBytes += cVar_init_f(&cVar_7ElgVXrf, 0.0f);
  numBytes += cVar_init_s(&cVar_WBvNNKwm, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_XWQnrYvV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qdLvFcPy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xou1b1nQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_ICeogdlY, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_jh2URA71, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o61hoSY0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Elwz8NWn, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_eghqVs3l, 0.0f);
  numBytes += cDelay_init(this, &cDelay_TwtFhQY4, 0.0f);
  numBytes += hTable_init(&hTable_GK32SWDU, 256);
  numBytes += cDelay_init(this, &cDelay_sXMnhsms, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Yg0sQ9Yw, 0.0f);
  numBytes += hTable_init(&hTable_5ZFAQ6nt, 256);
  numBytes += cVar_init_f(&cVar_fJsDI99M, 14.0f);
  numBytes += cBinop_init(&cBinop_HguHO3G0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_gb2moCli, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bu5uXUUc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_OFLFcYDk, 14.0f);
  numBytes += cBinop_init(&cBinop_sO2MJ7p8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lLGUS7PM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JY1vwv2O, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_QxDq3wDv, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_0acFTQnN, 1, -1);
  numBytes += cVar_init_f(&cVar_KJL5JBAp, 0.2f);
  numBytes += cSlice_init(&cSlice_74aqtSdG, 1, -1);
  numBytes += cVar_init_f(&cVar_x8rwYKOH, 0.0f);
  numBytes += cSlice_init(&cSlice_wKW84zVO, 1, -1);
  numBytes += cVar_init_f(&cVar_8CsXhpSN, 2.0f);
  numBytes += cSlice_init(&cSlice_EI1QlaiN, 1, -1);
  numBytes += cVar_init_f(&cVar_vuHfEzrJ, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_GK32SWDU);
  hTable_free(&hTable_5ZFAQ6nt);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_GK32SWDU; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_5ZFAQ6nt; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zLUoSYm0_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MXsdU0CX_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Be3V9zoO_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qUMORgVh_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2ed9fGc8_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LpFT8Smw_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fd7JSyTX_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gG8lQPVG_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DyTaBMaN_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_bmNDR1OK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OZgjtR7u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_JK7Fao6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rcd59JTm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_lvnEk7ka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aVOjCRAv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_7ElgVXrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MEcfx2ZH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_GaZNJ3Yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XbtXwXVj_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_XbtXwXVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_RwgZHe59, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_MOfF5LZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hA6XBq4E_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_hA6XBq4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iVBHDPMs_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_WBvNNKwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lOfNgneW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_UjxADmLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YHcC4YcG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XWQnrYvV, m);
}

void Heavy_WSTD_FLANGR::cBinop_iVBHDPMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qdLvFcPy, m);
}

void Heavy_WSTD_FLANGR::cMsg_lOfNgneW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UjxADmLC_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_YHcC4YcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xou1b1nQ, m);
}

void Heavy_WSTD_FLANGR::cMsg_cwLOyEB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fKIyULWG_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_fKIyULWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_r80ZFGEU_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_ICeogdlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4hdP4TMy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_hDUd3fLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9oEpShbV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jh2URA71, m);
}

void Heavy_WSTD_FLANGR::cBinop_r80ZFGEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_o61hoSY0, m);
}

void Heavy_WSTD_FLANGR::cMsg_4hdP4TMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hDUd3fLd_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9oEpShbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Elwz8NWn, m);
}

void Heavy_WSTD_FLANGR::cBinop_AdUDuMyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Giec0h4H_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Giec0h4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_YaATgDdy_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_i0Lypy8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d4mO89NU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_S7TNBO5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EgI67XxD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_YaATgDdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_S7JJL6KI_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_S7JJL6KI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_axI1RraL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oMUZFIAD_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_axI1RraL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pQa8RXob_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_oMUZFIAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hTM8NZa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_pQa8RXob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iJpOtSlF_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_hTM8NZa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_N3O1TWvX_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_N3O1TWvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hEl7vK59_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_iJpOtSlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_i0Lypy8n_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_hEl7vK59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_S7TNBO5N_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_mXwPG1X3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XrYXN3OM_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_XrYXN3OM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tGx583hW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_Rf7RsUN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WtzMs1iK_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_WtzMs1iK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4QEemtpn_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_eghqVs3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eghqVs3l, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TwtFhQY4, 0, m, &cDelay_TwtFhQY4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eghqVs3l, 0, m, &cDelay_eghqVs3l_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9MG4p8NN, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_TwtFhQY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TwtFhQY4, m);
  cMsg_WFZu24ed_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_Xfid5Onr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_nRF8KkdF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_ubSzAum3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HakrrnKs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_GK32SWDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uE7gw4uY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eghqVs3l, 2, m, &cDelay_eghqVs3l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N6lWLLTE_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_HakrrnKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_GK32SWDU, 0, m, &hTable_GK32SWDU_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_4QEemtpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_ubSzAum3_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_WFZu24ed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_GK32SWDU, 0, m, &hTable_GK32SWDU_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_N6lWLLTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eghqVs3l, 0, m, &cDelay_eghqVs3l_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_uE7gw4uY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_TwtFhQY4, 2, m, &cDelay_TwtFhQY4_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_nRF8KkdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9MG4p8NN, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_kylZwhCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xd33hfNU_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_Xd33hfNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ztv95opG_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_sXMnhsms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sXMnhsms, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Yg0sQ9Yw, 0, m, &cDelay_Yg0sQ9Yw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sXMnhsms, 0, m, &cDelay_sXMnhsms_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_M0POJ8FO, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_Yg0sQ9Yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Yg0sQ9Yw, m);
  cMsg_gFWIbRuw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_bQdWJQAY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_cZmjsvh9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_22GLzVzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IGkZOSie_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_5ZFAQ6nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CEWZ1byP_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sXMnhsms, 2, m, &cDelay_sXMnhsms_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MWOdW5GG_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_IGkZOSie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5ZFAQ6nt, 0, m, &hTable_5ZFAQ6nt_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ztv95opG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_22GLzVzz_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_gFWIbRuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5ZFAQ6nt, 0, m, &hTable_5ZFAQ6nt_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_MWOdW5GG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sXMnhsms, 0, m, &cDelay_sXMnhsms_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_CEWZ1byP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Yg0sQ9Yw, 2, m, &cDelay_Yg0sQ9Yw_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_cZmjsvh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_M0POJ8FO, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_fJsDI99M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HguHO3G0, HV_BINOP_MULTIPLY, 0, m, &cBinop_HguHO3G0_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_QyqlxxZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S1zYhqor_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_S1zYhqor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GHGF3Bif_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_HguHO3G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_FElkQWip_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Y0cR4aoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HguHO3G0, HV_BINOP_MULTIPLY, 1, m, &cBinop_HguHO3G0_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_GHGF3Bif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Y0cR4aoG_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_FElkQWip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_W8xfVPm1_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_W8xfVPm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BhOGETxf_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bu5uXUUc, m);
}

void Heavy_WSTD_FLANGR::cBinop_BhOGETxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gb2moCli, m);
}

void Heavy_WSTD_FLANGR::cVar_OFLFcYDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sO2MJ7p8, HV_BINOP_MULTIPLY, 0, m, &cBinop_sO2MJ7p8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_i9g2TiZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ufbOuqQc_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_ufbOuqQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_euccjQ7b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_sO2MJ7p8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_O0NStfiN_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_h6Sw249B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sO2MJ7p8, HV_BINOP_MULTIPLY, 1, m, &cBinop_sO2MJ7p8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_euccjQ7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_h6Sw249B_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_O0NStfiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ghSPmNjK_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ghSPmNjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KLthloJp_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JY1vwv2O, m);
}

void Heavy_WSTD_FLANGR::cBinop_KLthloJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lLGUS7PM, m);
}

void Heavy_WSTD_FLANGR::cMsg_tGx583hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IA2xiq1W, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_ETqOciFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_4Df4NTVY_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_kZjGIvpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ui73Xcbx_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_y7Q03ria_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_ETqOciFM_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_8Kuv9X8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yBwjXpWh_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_yBwjXpWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QxDq3wDv, HV_BINOP_MULTIPLY, 1, m, &cBinop_QxDq3wDv_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ui73Xcbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_8Kuv9X8F_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QxDq3wDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_truXuQNL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_4Df4NTVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QxDq3wDv, HV_BINOP_MULTIPLY, 0, m, &cBinop_QxDq3wDv_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_truXuQNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_45lME5CF, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_XZlsc20h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_UlASe6hz_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_UlASe6hz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kZjGIvpN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y7Q03ria_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_rme0D43Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0acFTQnN, 0, m, &cSlice_0acFTQnN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YMoMU3N8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_0acFTQnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RuCsdTBj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RuCsdTBj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_KJL5JBAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RuCsdTBj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_RuCsdTBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LpFT8Smw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_YMoMU3N8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_74aqtSdG, 0, m, &cSlice_74aqtSdG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_W0HhlLJe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_74aqtSdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ySFP5qLL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ySFP5qLL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_x8rwYKOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ySFP5qLL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_ySFP5qLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2ed9fGc8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_W0HhlLJe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wKW84zVO, 0, m, &cSlice_wKW84zVO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1yUMyezh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_wKW84zVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2KvwIRvX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2KvwIRvX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_8CsXhpSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2KvwIRvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_2KvwIRvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gG8lQPVG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_1yUMyezh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EI1QlaiN, 0, m, &cSlice_EI1QlaiN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_EI1QlaiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CUFvzKUY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CUFvzKUY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_vuHfEzrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CUFvzKUY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_CUFvzKUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fd7JSyTX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_d4mO89NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wIVYSpXS, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_EgI67XxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cxoNSdWS, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_MEcfx2ZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_rme0D43Z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_OZgjtR7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_rme0D43Z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Rcd59JTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_rme0D43Z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_aVOjCRAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_rme0D43Z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_JxPnAzVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7ElgVXrf, 0, m, &cVar_7ElgVXrf_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QmCxDwnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bmNDR1OK, 0, m, &cVar_bmNDR1OK_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_v7VTjZGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lvnEk7ka, 0, m, &cVar_lvnEk7ka_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_gG8lQPVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_GaZNJ3Yk_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_2ed9fGc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XZlsc20h_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_DyTaBMaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QyqlxxZs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fJsDI99M, 0, m, &cVar_fJsDI99M_sendMessage);
  cMsg_i9g2TiZ6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OFLFcYDk, 0, m, &cVar_OFLFcYDk_sendMessage);
  cMsg_Rf7RsUN9_sendMessage(_c, 0, m);
  cMsg_kylZwhCC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KJL5JBAp, 0, m, &cVar_KJL5JBAp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x8rwYKOH, 0, m, &cVar_x8rwYKOH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8CsXhpSN, 0, m, &cVar_8CsXhpSN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vuHfEzrJ, 0, m, &cVar_vuHfEzrJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WBvNNKwm, 0, m, &cVar_WBvNNKwm_sendMessage);
  cMsg_MOfF5LZZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ICeogdlY, 0, m, &cVar_ICeogdlY_sendMessage);
  cMsg_cwLOyEB2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_fd7JSyTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AdUDuMyy_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_LpFT8Smw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mXwPG1X3_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_qUMORgVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JK7Fao6W, 0, m, &cVar_JK7Fao6W_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_Be3V9zoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_JxPnAzVX_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_MXsdU0CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_v7VTjZGf_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_zLUoSYm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QmCxDwnv_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_cxoNSdWS, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_RwgZHe59, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_IA2xiq1W, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_Bu5uXUUc, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_gb2moCli, VOf(Bf3));
    __hv_rpole_f(&sRPole_Y8PF3DRs, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_JY1vwv2O, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_lLGUS7PM, VOf(Bf4));
    __hv_rpole_f(&sRPole_zAOBbCX4, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_qMSZysbV, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_qdLvFcPy, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_xou1b1nQ, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_XWQnrYvV, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Upfpy28a, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_lxH2Tfdi, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_wIVYSpXS, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_njW7YN9k, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_o61hoSY0, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Elwz8NWn, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_jh2URA71, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_2vsqbJxw, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_TkHFRHl0, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_45lME5CF, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_9MG4p8NN, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_M0POJ8FO, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
