/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvSignalTabread.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"
#include "HvSignalDel1.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvSignalPhasor.h"
#include "HvSignalVar.h"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvSignalTabwrite.h"
#include "HvControlSlice.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_bmNDR1OK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JK7Fao6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lvnEk7ka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7ElgVXrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GaZNJ3Yk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XbtXwXVj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MOfF5LZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hA6XBq4E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WBvNNKwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UjxADmLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iVBHDPMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lOfNgneW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YHcC4YcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cwLOyEB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fKIyULWG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ICeogdlY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hDUd3fLd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r80ZFGEU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4hdP4TMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9oEpShbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AdUDuMyy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Giec0h4H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_i0Lypy8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_S7TNBO5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YaATgDdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S7JJL6KI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_axI1RraL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oMUZFIAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pQa8RXob_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hTM8NZa4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N3O1TWvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iJpOtSlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hEl7vK59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mXwPG1X3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XrYXN3OM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rf7RsUN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WtzMs1iK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_eghqVs3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TwtFhQY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Xfid5Onr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ubSzAum3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_GK32SWDU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HakrrnKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4QEemtpn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WFZu24ed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N6lWLLTE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uE7gw4uY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nRF8KkdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kylZwhCC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xd33hfNU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sXMnhsms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Yg0sQ9Yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bQdWJQAY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_22GLzVzz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5ZFAQ6nt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IGkZOSie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ztv95opG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gFWIbRuw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MWOdW5GG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CEWZ1byP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cZmjsvh9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fJsDI99M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QyqlxxZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_S1zYhqor_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HguHO3G0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y0cR4aoG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GHGF3Bif_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FElkQWip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W8xfVPm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BhOGETxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OFLFcYDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i9g2TiZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ufbOuqQc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sO2MJ7p8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h6Sw249B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_euccjQ7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O0NStfiN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ghSPmNjK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KLthloJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tGx583hW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ETqOciFM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kZjGIvpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y7Q03ria_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Kuv9X8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yBwjXpWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ui73Xcbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QxDq3wDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Df4NTVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_truXuQNL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XZlsc20h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UlASe6hz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rme0D43Z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_0acFTQnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KJL5JBAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RuCsdTBj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YMoMU3N8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_74aqtSdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x8rwYKOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ySFP5qLL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_W0HhlLJe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_wKW84zVO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8CsXhpSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2KvwIRvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1yUMyezh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_EI1QlaiN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vuHfEzrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CUFvzKUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d4mO89NU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EgI67XxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MEcfx2ZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OZgjtR7u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rcd59JTm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aVOjCRAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JxPnAzVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QmCxDwnv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v7VTjZGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gG8lQPVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2ed9fGc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DyTaBMaN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fd7JSyTX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LpFT8Smw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qUMORgVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Be3V9zoO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MXsdU0CX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zLUoSYm0_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_cxoNSdWS;
  SignalPhasor sPhasor_RwgZHe59;
  SignalLine sLine_IA2xiq1W;
  SignalRPole sRPole_Y8PF3DRs;
  SignalRPole sRPole_zAOBbCX4;
  SignalTabhead sTabhead_qMSZysbV;
  SignalTabread sTabread_Upfpy28a;
  SignalTabread sTabread_lxH2Tfdi;
  SignalLine sLine_wIVYSpXS;
  SignalTabhead sTabhead_njW7YN9k;
  SignalTabread sTabread_2vsqbJxw;
  SignalTabread sTabread_TkHFRHl0;
  SignalLine sLine_45lME5CF;
  SignalTabwrite sTabwrite_9MG4p8NN;
  SignalTabwrite sTabwrite_M0POJ8FO;
  ControlVar cVar_bmNDR1OK;
  ControlVar cVar_JK7Fao6W;
  ControlVar cVar_lvnEk7ka;
  ControlVar cVar_7ElgVXrf;
  ControlBinop cBinop_GaZNJ3Yk;
  ControlBinop cBinop_XbtXwXVj;
  ControlVar cVar_WBvNNKwm;
  ControlBinop cBinop_iVBHDPMs;
  ControlBinop cBinop_YHcC4YcG;
  SignalVarf sVarf_XWQnrYvV;
  SignalVarf sVarf_qdLvFcPy;
  SignalVarf sVarf_xou1b1nQ;
  ControlVar cVar_ICeogdlY;
  ControlBinop cBinop_r80ZFGEU;
  ControlBinop cBinop_9oEpShbV;
  SignalVarf sVarf_jh2URA71;
  SignalVarf sVarf_o61hoSY0;
  SignalVarf sVarf_Elwz8NWn;
  ControlBinop cBinop_AdUDuMyy;
  ControlBinop cBinop_Giec0h4H;
  ControlBinop cBinop_YaATgDdy;
  ControlBinop cBinop_S7JJL6KI;
  ControlBinop cBinop_pQa8RXob;
  ControlBinop cBinop_N3O1TWvX;
  ControlBinop cBinop_iJpOtSlF;
  ControlBinop cBinop_hEl7vK59;
  ControlBinop cBinop_mXwPG1X3;
  ControlBinop cBinop_XrYXN3OM;
  ControlDelay cDelay_eghqVs3l;
  ControlDelay cDelay_TwtFhQY4;
  ControlBinop cBinop_ubSzAum3;
  HvTable hTable_GK32SWDU;
  ControlBinop cBinop_4QEemtpn;
  ControlDelay cDelay_sXMnhsms;
  ControlDelay cDelay_Yg0sQ9Yw;
  ControlBinop cBinop_22GLzVzz;
  HvTable hTable_5ZFAQ6nt;
  ControlBinop cBinop_ztv95opG;
  ControlVar cVar_fJsDI99M;
  ControlBinop cBinop_HguHO3G0;
  ControlBinop cBinop_Y0cR4aoG;
  SignalVarf sVarf_gb2moCli;
  ControlBinop cBinop_FElkQWip;
  ControlBinop cBinop_W8xfVPm1;
  ControlBinop cBinop_BhOGETxf;
  SignalVarf sVarf_Bu5uXUUc;
  ControlVar cVar_OFLFcYDk;
  ControlBinop cBinop_sO2MJ7p8;
  ControlBinop cBinop_h6Sw249B;
  SignalVarf sVarf_lLGUS7PM;
  ControlBinop cBinop_O0NStfiN;
  ControlBinop cBinop_ghSPmNjK;
  ControlBinop cBinop_KLthloJp;
  SignalVarf sVarf_JY1vwv2O;
  ControlBinop cBinop_8Kuv9X8F;
  ControlBinop cBinop_yBwjXpWh;
  ControlBinop cBinop_ui73Xcbx;
  ControlBinop cBinop_QxDq3wDv;
  ControlBinop cBinop_4Df4NTVY;
  ControlBinop cBinop_XZlsc20h;
  ControlBinop cBinop_UlASe6hz;
  ControlSlice cSlice_0acFTQnN;
  ControlVar cVar_KJL5JBAp;
  ControlSlice cSlice_74aqtSdG;
  ControlVar cVar_x8rwYKOH;
  ControlSlice cSlice_wKW84zVO;
  ControlVar cVar_8CsXhpSN;
  ControlSlice cSlice_EI1QlaiN;
  ControlVar cVar_vuHfEzrJ;
  ControlBinop cBinop_JxPnAzVX;
  ControlBinop cBinop_QmCxDwnv;
  ControlBinop cBinop_v7VTjZGf;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
